==> tuia-advert-center-api-1.5.9-20180816.022344-58-sources.jar: cn/com/duiba/tuia/core/api/dto/app/AdvertDataDto.java <==
package cn.com.duiba.tuia.core.api.dto.app;

public class AdvertDataDto {

    public static final int NOT_BIND         = 0;

    public static final int IS_BIND          = 1;

    public static final int CAN_DELIVERY     = 0;

    public static final int CAN_NOT_DELIVERY = 1;
    /** 广告计划ID. */
    private Long            advertId;

    /** 广告计划名称. */
    private String          advertName;

    private String          companyName;
    private String          agentCompanyName;
    /** 广告状态. */
    private Integer         checkStatus;
    /** 开始时间. */
    private String          startDate;
    /** 结束时间. */
    private String          endDate;
    /** 操作状态：0-未绑定,1-已绑定. */
    private int             operateStatus    = 0;
    private Double          arpu;
    /** 广告每日预算 */
    private Long            budget;
    /** 是否可投放 0(可以投放)，1（不可投放） */
    private Integer         canDelivery;
    /** 不可投放原因 */
    private String          reason;

    public String getAdvertName() {
        return advertName;
    }

    public void setAdvertName(String advertName) {
        this.advertName = advertName;
    }

    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }

    public String getAgentCompanyName() {
        return agentCompanyName;
    }

    public void setAgentCompanyName(String agentCompanyName) {
        this.agentCompanyName = agentCompanyName;
    }

    public Long getBudget() {
        return budget;
    }

    public void setBudget(Long budget) {
        this.budget = budget;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Integer getCheckStatus() {
        return checkStatus;
    }

    public void setCheckStatus(Integer checkStatus) {
        this.checkStatus = checkStatus;
    }

    public String getStartDate() {
        return startDate;
    }

    public void setStartDate(String startDate) {
        this.startDate = startDate;
    }

    public String getEndDate() {
        return endDate;
    }

    public void setEndDate(String endDate) {
        this.endDate = endDate;
    }

    public int getOperateStatus() {
        return operateStatus;
    }

    public void setOperateStatus(int operateStatus) {
        this.operateStatus = operateStatus;
    }

    public Double getArpu() {
        return arpu;
    }

    public void setArpu(Double arpu) {
        this.arpu = arpu;
    }

    public Integer getCanDelivery() {
        return canDelivery;
    }

    public void setCanDelivery(Integer canDelivery) {
        this.canDelivery = canDelivery;
    }

    public String getReason() {
        return reason;
    }

    public void setReason(String reason) {
        this.reason = reason;
    }
}

==> tuia-advert-center-api-2.4.3-sources.jar: cn/com/duiba/tuia/core/api/dto/app/AdvertDataDto.java <==
package cn.com.duiba.tuia.core.api.dto.app;

import java.io.Serializable;

public class AdvertDataDto  implements Serializable {

    public static final int NOT_BIND         = 0;

    public static final int IS_BIND          = 1;

    public static final int CAN_DELIVERY     = 0;

    public static final int CAN_NOT_DELIVERY = 1;
    private static final long serialVersionUID = 1589364748127208601L;
    /** 广告计划ID. */
    private Long            advertId;
    //广告类型
    private Integer advertType;

    /** 广告计划名称. */
    private String          advertName;

    private String          companyName;
    private String          agentCompanyName;
    /** 广告状态. */
    private Integer         checkStatus;
    /** 开始时间. */
    private String          startDate;
    /** 结束时间. */
    private String          endDate;
    /** 操作状态：0-未绑定,1-已绑定. */
    private int             operateStatus    = 0;
    private Double          arpu;
    /** 广告每日预算 */
    private Long            budget;
    /** 是否可投放 0(可以投放)，1（不可投放） */
    private Integer         canDelivery;
    /** 不可投放原因 */
    private String          reason;

    public String getAdvertName() {
        return advertName;
    }

    public void setAdvertName(String advertName) {
        this.advertName = advertName;
    }

    public Integer getAdvertType() {
        return advertType;
    }

    public void setAdvertType(Integer advertType) {
        this.advertType = advertType;
    }

    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }

    public String getAgentCompanyName() {
        return agentCompanyName;
    }

    public void setAgentCompanyName(String agentCompanyName) {
        this.agentCompanyName = agentCompanyName;
    }

    public Long getBudget() {
        return budget;
    }

    public void setBudget(Long budget) {
        this.budget = budget;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Integer getCheckStatus() {
        return checkStatus;
    }

    public void setCheckStatus(Integer checkStatus) {
        this.checkStatus = checkStatus;
    }

    public String getStartDate() {
        return startDate;
    }

    public void setStartDate(String startDate) {
        this.startDate = startDate;
    }

    public String getEndDate() {
        return endDate;
    }

    public void setEndDate(String endDate) {
        this.endDate = endDate;
    }

    public int getOperateStatus() {
        return operateStatus;
    }

    public void setOperateStatus(int operateStatus) {
        this.operateStatus = operateStatus;
    }

    public Double getArpu() {
        return arpu;
    }

    public void setArpu(Double arpu) {
        this.arpu = arpu;
    }

    public Integer getCanDelivery() {
        return canDelivery;
    }

    public void setCanDelivery(Integer canDelivery) {
        this.canDelivery = canDelivery;
    }

    public String getReason() {
        return reason;
    }

    public void setReason(String reason) {
        this.reason = reason;
    }
}
